﻿using System;

namespace Parade.Metadata.Asf
{
	/// <summary>
	/// ASF の GUID 定数を定義します。
	/// </summary>
	static class Guids
	{
		/// <summary>
		/// クラスを初期化します。
		/// </summary>
		static Guids()
		{
			Guids.CodecListObject                  = new Guid( "86D15240-311D-11D0-A3A4-00A0C90348F6" );
			Guids.ContentEncryptionObject          = new Guid( "2211B3FB-BD23-11D2-B4B7-00A0C955FC6E" );
			Guids.ContentBrandingObject            = new Guid( "2211B3FA-BD23-11D2-B4B7-00A0C955FC6E" );
			Guids.ContentDescriptionObject         = new Guid( "75B22633-668E-11CF-A6D9-00AA0062CE6C" );
			Guids.DataObject                       = new Guid( "75B22636-668E-11CF-A6D9-00AA0062CE6C" );
			Guids.ExtendedContentDescriptionObject = new Guid( "D2D0A440-E307-11D2-97F0-00A0C95EA850" );
			Guids.ExtendedContentEncryptionObject  = new Guid( "298AE614-2622-4C17-B935-DAE07EE9289C" );
			Guids.ExtendedStreamPropertiesObject   = new Guid( "14E6A5CB-C672-4332-8399-A96952065B5A" );
			Guids.FilePropertiesObject             = new Guid( "8CABDCA1-A947-11CF-8EE4-00C00C205365" );
			Guids.HeaderExtensionObject            = new Guid( "5FBF03B5-A92E-11CF-8EE3-00C00C205365" );
			Guids.HeaderObject                     = new Guid( "75B22630-668E-11CF-A6D9-00AA0062CE6C" );
			Guids.LanguageListObject               = new Guid( "7C4346A9-EFE0-4BFC-B229-393EDE415C85" );
			Guids.MetadataLibraryObject            = new Guid( "44231C94-9498-49D1-A141-1D134E457054" );
			Guids.MetadataObject                   = new Guid( "C5F8CBEA-5BAF-4877-8467-AA8C44FA4CCA" );
			Guids.PaddingObject                    = new Guid( "1806D474-CADF-4509-A4BA-9AABCB96AAE8" );
			Guids.StreamBitratePropertiesObject    = new Guid( "7BF875CE-468D-11D1-8D82-006097C9A2B2" );
			Guids.StreamPrioritizationObject       = new Guid( "D4FED15B-88D3-454F-81F0-ED5C45999E24" );
			Guids.StreamPropertiesObject           = new Guid( "B7DC0791-A9B7-11CF-8EE6-00C00C205365" );
			Guids.VideoMedia                       = new Guid( "BC19EFC0-5B4D-11CF-A8FD-00805F5C442B" );
		}

		/// <summary>
		/// コーデック情報を表す値を取得します。
		/// </summary>
		public static Guid CodecListObject { get; private set; }

		/// <summary>
		/// コンテンツのブランディング情報を表す値を取得します。
		/// </summary>
		public static Guid ContentBrandingObject { get; private set; }

		/// <summary>
		/// コンテンツ情報を表す値を取得します。
		/// </summary>
		public static Guid ContentDescriptionObject { get; private set; }

		/// <summary>
		/// コンテンツの暗号化情報を表す値を取得します。
		/// </summary>
		public static Guid ContentEncryptionObject { get; private set; }

		/// <summary>
		/// 音声・動画データを表す値を取得します。
		/// </summary>
		public static Guid DataObject { get; private set; }

		/// <summary>
		/// 言語に依存しないタグ情報を表す値を取得します。
		/// </summary>
		public static Guid ExtendedContentDescriptionObject { get; private set; }

		/// <summary>
		/// コンテンツ暗号化の拡張情報を表す値を取得します。
		/// </summary>
		public static Guid ExtendedContentEncryptionObject { get; private set; }

		/// <summary>
		/// Header Extension Object 内における、拡張ストーリーム情報を表す値を取得します。
		/// </summary>
		public static Guid ExtendedStreamPropertiesObject { get; private set; }

		/// <summary>
		/// ファイル情報を表す値を取得します。
		/// </summary>
		public static Guid FilePropertiesObject { get; private set; }

		/// <summary>
		/// 拡張ヘッダ情報を表す値を取得します。
		/// </summary>
		public static Guid HeaderExtensionObject { get; private set; }	

		/// <summary>
		/// ASF ファイルのヘッダ情報を表す値を取得します。
		/// </summary>
		public static Guid HeaderObject { get; private set; }
		
		/// <summary>
		/// Header Extension Object 内における、言語リストを表す値を取得します。
		/// </summary>
		public static Guid LanguageListObject { get; private set; }

		/// <summary>
		/// Header Extension Object 内における、言語依存のメタデータを表す値を取得します。
		/// </summary>
		public static Guid MetadataLibraryObject { get; private set; }

		/// <summary>
		/// Header Extension Object 内における、言語に依存しないメタデータを表す値を取得します。
		/// </summary>
		public static Guid MetadataObject { get; private set; }

		/// <summary>
		/// 余白を表す値を取得します。
		/// </summary>
		public static Guid PaddingObject { get; private set; }

		/// <summary>
		/// ストリームのビットレート情報を表す値を取得します。
		/// </summary>
		public static Guid StreamBitratePropertiesObject { get; private set; }
		
		/// <summary>
		/// Header Extension Object 内における、ストリームの優先度情報を表す値を取得します。
		/// </summary>
		public static Guid StreamPrioritizationObject { get; private set; }

		/// <summary>
		/// ストリーム情報を表す値を取得します。
		/// </summary>
		public static Guid StreamPropertiesObject { get; private set; }	
	
		/// <summary>
		/// ストリームがビデオであることを示す値を取得します。
		/// </summary>
		public static Guid VideoMedia { get; private set; }
	}
}
