﻿
namespace Parade.Metadata.Asf
{
	/// <summary>
	/// タグの読み書きをおこなうための情報を格納します。
	/// </summary>
	class TagData
	{
		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		/// <param name="position">ストーリム上の読み出し位置 ( バイト単位 )。</param>
		/// <param name="length">ストリームから読み取るサイズ ( バイト単位 )。</param>
		/// <param name="type">データ型。</param>
		/// <param name="value">書き込み候補、または複数の値から算出された情報をキャッシュした値。</param>
		public TagData( long position, int length, TagDataType type, object value )
		{
			this.Position = position;
			this.Length   = length;
			this.Type     = type;
			this.Value    = value;
		}

		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		/// <param name="position">ストーリム上の読み出し位置 ( バイト単位 )。</param>
		/// <param name="length">ストリームから読み取るサイズ ( バイト単位 )。</param>
		/// <param name="type">データ型。</param>
		public TagData( long position, int length, TagDataType type )
			: this( position, length, type, null )
		{
		}

		/// <summary>
		/// 削除されることを示す値を取得または設定します。
		/// </summary>
		public bool IsRemove { get; set; }

		/// <summary>
		/// ストリームから読み取るサイズ ( バイト単位 ) を取得します。
		/// </summary>
		public int Length { get; private set; }

		/// <summary>
		/// ストーリム上の読み出し位置 ( バイト単位 ) を取得します。
		/// </summary>
		public long Position { get; private set; }

		/// <summary>
		/// データ型を取得します。
		/// この値は AsfTagDataType と一致しないことがあるので注意してください。
		/// </summary>
		public TagDataType Type { get; private set; }

		/// <summary>
		/// 書き込み候補、または複数の値から算出された情報をキャッシュした値を、取得または設定します。
		/// </summary>
		public object Value { get; set; }
	}
}
