﻿using System;
using System.Diagnostics;
using System.IO;
using System.Reflection;
using System.Text;
using Parade.Metadata.Asf;

namespace TestApp
{
	/// <summary>
	/// 
	/// </summary>
	class Program
	{
		/// <summary>
		/// プログラムのエントリポイントです。
		/// </summary>
		/// <param name="args">コマンドライン引数。</param>
		static void Main( string[] args )
		{
			//Program.Dump( args );
			Program.Read( args );
		}

		/// <summary>
		/// ASF ファイルの内容を通常のタグ読み取りメソッドを使用してダンプします。
		/// </summary>
		/// <param name="args">コマンドライン引数。</param>
		private static void Read( string[] args )
		{
			try
			{
				string dumpFileName;
				{
					var dir = Path.GetDirectoryName( Assembly.GetEntryAssembly().Location );
					dumpFileName = dir + "\\dump.txt";
				}

				// 前回、出力されてたテキストがあれば削除する
				if( File.Exists( dumpFileName ) && args.Length > 0 )
				{
					File.Delete( dumpFileName );
				}

				using( var w = new StreamWriter( dumpFileName, true, Encoding.Unicode ) )
				{
					// 引数指定された ASF ファイルのタグ情報をまとめて出力
					for( int i = 0; i < args.Length; ++i )
					{
						w.WriteLine( "\nFile : {0}\nName\tValue", args[ i ] );
						using( var e = new AsfTagEditor( args[ i ] ) )
						{
							foreach( var name in AsfDefinedTags.GetNames() )
							{
								var value = e.Read( name );
								if( value == null ) { continue; }

								var info  = AsfDefinedTags.GetInfo( name );

								if( name == AsfDefinedTags.Duration.Name )
								{
									var time = new TimeSpan( ( long )( ulong )value );
									w.WriteLine( "{0}\t{1}", name, time );
								}
								else
								{
									w.WriteLine( "{0}\t{1}", name, ( info.Type == AsfTagDataType.Binary ? "Bytes..." : value.ToString() ) );
								}

							}
						}
					}
				}
			}
			catch( Exception e )
			{
				Debug.WriteLine( e );
			}
		}

		/// <summary>
		/// ASF ファイルの内容をダンプします。
		/// </summary>
		/// <param name="args">コマンドライン引数。</param>
		private static void Dump( string[] args )
		{
			try
			{
				string dumpFileName;
				{
					var dir = Path.GetDirectoryName( Assembly.GetEntryAssembly().Location );
					dumpFileName = dir + "\\dump.txt";
				}

				// 前回、出力されてたテキストがあれば削除する
				if( File.Exists( dumpFileName ) && args.Length > 0 )
				{
					File.Delete( dumpFileName );
				}

				// 引数指定された ASF ファイルのタグ情報をまとめて出力
				for( int i = 0; i < args.Length; ++i )
				{
					AsfTagEditor.Dump( args[ i ], dumpFileName );
				}
			}
			catch( Exception e )
			{
				Debug.WriteLine( e );
			}
		}
	}
}
